@@ -1,28 +1,8 @@
-".createChron" <- function(date, time, dtformat=c("d/m/y", "h:m:s"))
-{
-    ## Purpose: Create a chron object from date and time
-    ## --------------------------------------------------------------------
-    ## Arguments: date=time=date and timevectors, respectively, the latter
-    ## can be missing, dtformat=chron format for interpreting the above
-    ## --------------------------------------------------------------------
-    ## Author: Sebastian Luque
-    ## --------------------------------------------------------------------
-    if (is.null(time)) {
-        splitdate <- strsplit(date, " ")
-        chron(dates=sapply(splitdate, "[", 1),
-              times=sapply(splitdate, "[", 2),
-              format=dtformat)
-    } else {
-        chron(dates=date, times=time, format=dtformat)
-    }
-}
-
-
 ".getInterval" <- function(time)
 {
-    ## Purpose: Get the mode of intervals between time readings
+    ## Value: numeric; the mode of intervals between time readings
     ## --------------------------------------------------------------------
-    ## Arguments: time=chron object (no missing values allowed)
+    ## Arguments: time=POSIXct
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
@@ -30,21 +10,24 @@
     if (length(time) < 2) {
         interval <- 0
     } else {
-        tab <- table(diff(time))
+        tab <- table(difftime(time[-1], time[-length(time)],
+                              units="secs", tz="GMT"))
         interval <- as.numeric(names(tab[which.max(tab)]))
     }
-
     interval
 }
 
 
 "readTDR" <- function(file, dateCol=1, timeCol=2, depthCol=3, velCol=6,
-                      subsamp=5, dtformat=c("d/m/y", "h:m:s"))
+                      subsamp=5, dtformat="%d/%m/%Y %H:%M:%S", tz="GMT")
 {
-    ## Purpose: Read *.csv file and create an object of class tdr or tdrVel
+    ## Value: TDR or TDRvel object from *.csv file
     ## --------------------------------------------------------------------
-    ## Arguments: file=path to file to read;
-    ## subsamp=subsample the file at this interval
+    ## Arguments: file=path to file to read; dateCol=col no. with date,
+    ## timeCol=col no. with time, depthCol=col no. with depth, velCol=col
+    ## no. with velocity, subsamp=subsample at this interval,
+    ## dtformat=format to interpret the pasted date and time columns,
+    ## tz=time zone to assume
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
@@ -52,18 +35,15 @@
     tdrtype <- sub(".*(mk.).*", "\\1", tolower(srcfile))
     rawdat <- read.csv(file, header=TRUE,
                        na.strings="", as.is=TRUE)
-
-    datetime <- .createChron(rawdat[, dateCol], rawdat[, timeCol],
-                             dtformat=dtformat)
-
+    dtpasted <- paste(rawdat[, dateCol], rawdat[, timeCol])
+    datetime <- as.POSIXct(strptime(dtpasted, format=dtformat), tz=tz)
     origint <- .getInterval(datetime)
-    if(!identical(all.equal(origint, subsamp/86400), TRUE)) {
-        steptim <- as.numeric((subsamp/86400) / origint)
+    if(!identical(all.equal(origint, subsamp), TRUE)) {
+        steptim <- as.numeric((subsamp) / origint)
         stepind <- seq(from=1, to=length(datetime), by=round(steptim))
         datetime <- datetime[stepind]
         rawdat <- rawdat[stepind, ]
     }
-
     if (tdrtype != "mk8") {
         new("TDR", file=srcfile, time=datetime,
             depth=rawdat[, depthCol], dtime=.getInterval(datetime))
